function CC = NM4M_BaseCC(bases,p)

%convert spectral bases to cepstral coefficients. No mel scale applied
%because the bases are already on a logarithmic frequency axis. If this
%function is used p.dB_flag has to be zero! Also the parameter p.bpo should
%be set to 8 or higher instead of 4 when using the cepstral conversion.
% for full docu of the parameter structure see file NM4M_ParamInit.m
%
% Andre Holzapfel
% Master Thesis Implementation
% Signal Processing Laboratory
% University of Crete, June 2006
% Supervisor: Jannis Stylianou

%   Copyright (c) 2008 University of Crete.
% 
%   This file is part of Non-negative Matrix Factorization for Music (NM4M)
% 
%   NM4M is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License version 2 as
%   published by the Free Software Foundation.
% 
%   NM4M is distributed in the hope that it will be useful, but
%   WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%   General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with NM4M; if not, write to the Free Software
%   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
%   02110-1301 USA
% 
%   See the file "COPYING" for the text of the license.


p = NM4M_ParamInit(p);%set parameters to standard values if not set
num_filt = size(bases,1);%how many frequency bins do we use?
DCT = 1/sqrt(num_filt/2)*cos((1-p.use_first_coeff:(p.num_ceps_coeffs-p.use_first_coeff))' * (2*(0:(num_filt-1))+1) * pi/2/num_filt);
if p.use_first_coeff
    DCT(1,:) = DCT(1,:) * sqrt(2)/2;%construct DCT matrix
end
if p.dB_flag == 0
    bases(bases<1) = 1; %% for dB
    CC = DCT*10*log10(bases); %% compute dB and compress using DCT
else
    CC = DCT*10*bases;
end