function NM4M_CrossValList(DIR,p,ALT_NAME)

%look for folders in DIR. These have to contain classes with base vector
%files computed by NM4M_CompFeat
%If this file is run for the first time with a particular name
%ALT_NAME then a random choice for the train and test files is done writing
%a test list and a train list with the distribution 20 per cent to 80 per
%cent. If the files have been written already they are read and combined in
%a way that enables for a 5 fold cross validation. The function only has to
%be called every time before training and testing in five iterations.
%code partly taken from Michael Casey's MPEG7 reference implementation.
% for full docu of the parameter structure see file NM4M_ParamInit.m
%
%
%
% Andre Holzapfel
% Master Thesis Implementation
% Signal Processing Laboratory
% University of Crete, June 2006
% Supervisor: Jannis Stylianou

%   Copyright (c) 2008 University of Crete.
% 
%   This file is part of Non-negative Matrix Factorization for Music (NM4M)
% 
%   NM4M is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License version 2 as
%   published by the Free Software Foundation.
% 
%   NM4M is distributed in the hope that it will be useful, but
%   WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%   General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with NM4M; if not, write to the Free Software
%   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
%   02110-1301 USA
% 
%   See the file "COPYING" for the text of the license.


p = NM4M_ParamInit(p);%set parameters to standard values if not set

D = dir(DIR);k=0;
for i=1:length(D)
    if(D(i).isdir & ~(D(i).name(1) == '.'))
	k=k+1;
	soundDir(k)=D(i);
    songnum(k) = length(dir([fullfile( DIR, soundDir(k).name) '/*.wav']));
    end
end
if(k>0)
    ListExist = 0;
    for i=1:k
        if strcmp(p.spec,'logF')
            if (length(p.percentage) == 1)%same compression for all classes
                baseparmstr = ['_' num2str(p.percentage) '_' num2str(p.bpo) '_' num2str(p.winlength) '_' num2str(p.overlap) ...
                    '_' num2str(p.block) '_' num2str(p.decomp_meth) p.spec '.mat'];
            elseif (length(p.percentage) == k)%varying compression for the classes
                baseparmstr = ['_' num2str(p.percentage(i)) '_' num2str(p.bpo) '_' num2str(p.winlength) '_' num2str(p.overlap) ...
                    '_' num2str(p.block) '_' num2str(p.decomp_meth) p.spec '.mat'];
            else
                error(sprintf(['The percentage field has to be either a single number for equal compression of all classes \n' ...
                    'or a vector of the same length as the number of classes for class specific compression']));
            end
        elseif strcmp(p.spec,'sone')
            baseparmstr = ['_' num2str(p.percentage) '_' num2str(p.bpo) '_' num2str(p.winlength) '_' num2str(p.overlap) ...
                '_' num2str(p.block) '_' num2str(p.decomp_meth) p.spec '_' ...
                            p.outerear '_' num2str(p.do_spread) '.mat'];
        end
        ClassName{i} = fullfile( DIR, soundDir(i).name) ;
        TrainListName = fullfile(ClassName{i},[ALT_NAME '_TrainList.txt']);
        TestListName =  fullfile(ClassName{i},[ALT_NAME '_TestList.txt']);
        if (exist(TrainListName))%if list exists then do not create a random new one but proceed cross validation
            fprintf('Next Crossvalidation Step \n');
            ListExist = 1;
            break;
        end
        if p.force_list == 1;
            ListExist = 1;
            break;
        end
        fprintf('\nWriting Test and Train data lists for: %s\n', ClassName{i});
        TL=dir([ClassName{i} '/*' baseparmstr]);
        numFiles=length(TL);
        permut = randperm(numFiles);
        trainIndx=round(p.numcv*numFiles); % Use 80% of data for training, 20% for testing
        trainers=permut(1:trainIndx);
        testers=permut(trainIndx+1:end);
        fprintf('%s #Train: %d, #Test %d\n', ClassName{i}, length(trainers), length(testers)); 
        textwrite({TL(trainers).name}, TrainListName);%lists for base training
        textwrite({TL(testers).name}, TestListName);
        textwrite({TL(trainers).name}, fullfile(ClassName{i}, [ALT_NAME '_TrainList_'  num2str(p.crossrun) '_' ...
            num2str(p.num_clusters) '_' num2str(p.feature) '.txt']));
        textwrite({TL(testers).name}, fullfile(ClassName{i}, [ALT_NAME '_TestList_'  num2str(p.crossrun) '_' ...
            num2str(p.num_clusters) '_' num2str(p.feature) '.txt']));
    end
    if (ListExist == 1)%create new lists by interleving the old ones
        for i=1:k
            ClassName{i} = fullfile( DIR, soundDir(i).name) ;
            TrainListName = fullfile(ClassName{i},[ALT_NAME '_TrainList.txt']);
            filelist1 = readsfxfiles(TrainListName);
            TestListName = fullfile(ClassName{i},[ALT_NAME '_TestList.txt']);
            filelist2 = readsfxfiles(TestListName);
            NewTrainList = [filelist2;filelist1(1:(length(filelist1)-length(filelist2)))];
            NewTestList = filelist1( ((length(filelist1)-length(filelist2))+1) : (length(filelist1)) );
            textwrite(NewTrainList, TrainListName);
            textwrite(NewTestList, TestListName);
            textwrite(NewTrainList, fullfile(ClassName{i}, [ALT_NAME '_TrainList_'  num2str(p.crossrun) '_' ... 
                        num2str(p.num_clusters) '_' num2str(p.feature) '.txt']));
            textwrite(NewTestList, fullfile(ClassName{i}, [ALT_NAME '_TestList_'  num2str(p.crossrun) '_' ...
                        num2str(p.num_clusters) '_' num2str(p.feature) '.txt']));
        end
    end
    if p.force_list == 1
        fprintf('A specified list was forced to be read. Take care that it contains features according to the chosen parameters!\n');
    end
else
    fprintf('\nOoooops! There are no appropriate files.\n');
end
