function out_p = NM4M_ParamInit(p)
%sets the fields of p to the most probable settings if not defined by user
%
%
% Andre Holzapfel
% Master Thesis Implementation
% Signal Processing Laboratory
% University of Crete, June 2006
% Supervisor: Jannis Stylianou

%   Copyright (c) 2008 University of Crete.
% 
%   This file is part of Non-negative Matrix Factorization for Music (NM4M)
% 
%   NM4M is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License version 2 as
%   published by the Free Software Foundation.
% 
%   NM4M is distributed in the hope that it will be useful, but
%   WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%   General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with NM4M; if not, write to the Free Software
%   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
%   02110-1301 USA
% 
%   See the file "COPYING" for the text of the license.

%% defaults
if ~isfield(p,'bpo'),      p.bpo = 8;         end%how many bands per octave
if ~isfield(p,'winlength'),      p.winlength = 0.04;         end%fft window length in seconds
if ~isfield(p,'overlap'),      p.overlap = 0.5;         end%percentage of fft window overlap
if ~isfield(p,'block'),      p.block = 0.5;         end%length of the feature calculation window for NMF in seconds
if ~isfield(p,'decomp_meth'),      p.decomp_meth = 3;         end%use the Hoyer NMF algorithm
if ~isfield(p,'percentage'),      p.percentage = 3;         end%how much information to keep?, if set to value <40 a fixed number of componente
                                                                %is computed (3 components seem to be optimal)
                                                                %set the arguments used by the MA toolbox. The toolbox is used to calculate
                                                                %the sonograms of the audio files
if ~isfield(p,'fs'),      p.fs = 16000;         end%sampling frequency
if ~isfield(p,'dB_max'),      p.dB_max = 96;         end%the average SPL to normalize the data before calculating features
if ~isfield(p,'do_visu'),      p.do_visu = 0;         end%don't bother us with dozens of plots
if ~isfield(p,'block_hop') p.block_hop = 1; end%no overlap of the feature windows
if ~isfield(p,'crossrun') p.crossrun = 0; end %used to determine in which stepp of a cross validation we are
if ~isfield(p,'max_iter') p.max_iter = 50; end%maximum number of EM iterations for the GMM training
if ~isfield(p,'covar_type'), p.covar_type = 'full';end%for GMM, can be set to diag also, then netlab is used for the model training
if ~isfield(p,'baseCC') p.baseCC = 1; end % when set to one the spectral bases found by NMF are transformed to cepstral coefficients 
                                          % by using a DCT in the log
                                          % spectral bases
if ~isfield(p,'dB_flag') p.dB_flag = 0; end %convert spectral bases to dB and cut very small values. Must not be one when p.baseCC is one!
if ~isfield(p,'num_ceps_coeffs'), p.num_ceps_coeffs = 20; end %number of cepstral coefficients   
if ~isfield(p,'use_first_coeff'),  p.use_first_coeff = 0;  end %use the first coefficient containing energy?
if ~isfield(p,'spec'),  p.spec = 'logF';  end %logF: use a spectrogram on a logarithmic frequency scale (for taking dB amplitude values
                                              %p.dB_Flag has to be one
                                              %sone:use sonogram
                                              %representation as implemented by Elias Pampalk 
if ~isfield(p,'feature'), p.feature=1; end %NMF feature vertical type, to differentiate between NMF and MFCC(=2), and NMF horizontal features
                                            % (=3)
if ~isfield(p,'print_acc'),p.print_acc = 0;end %set to one if you want details on the classification printed to text files separately for each
                                               %class.
if ~isfield(p,'mc_samples'),p.mc_samples = 1000;end%4000;number of Monte Carlo samples, if distance measure is monte_carlo
if ~isfield(p,'cm_similarity'),p.cm_similarity = 'monte_carlo'; end%use monte carlo sampling
if ~isfield(p,'force_list'),p.force_list = 0; end %set to one if you do not want a Training list to be randomly created but to be read as is
if ~isfield(p,'decorr'),p.decorr = 0; end
if ~isfield(p,'do_spread'), p.do_spread = 1;         end
if ~isfield(p,'outerear'),  p.outerear = 'terhardt'; end
if ~isfield(p,'neighbours'),  p.neighbours = 5; end
if ~isempty(find(p.decomp_meth==[1 2])) 
    p.dB_min = -100;
elseif p.decomp_meth == 3
    p.dB_min = 0.001; %must be positive for NMF! We do not cut much as avg SPL has been set to dB_max dB
else
    error('This decomposition option not supported!');
end
    
if ~isfield(p,'numcv'), p.numcv = 0.8; end%0.8 for five fold, 0.9 for 10 fold
% the following parameters are for compatibility with the MA toolbox and
% are only used when setting p.spec to sone
p.fft_size = p.fs * p.winlength;%size of the fft window in samples
p.hopsize = p.fft_size * (1-p.overlap);% size of the hop in samples
if ~isfield(p,'bark_type'), p.bark_type = [62.5 8000 (7*p.bpo)]; end%sets low/high freq bounds and the spectral resolution in each of the 7 octaves
p.fft_hopsize = p.fft_size * (1-p.overlap);% size of the hop in samples
      p.sequence.length = 2*p.fft_size;   %% windows size (ca 6sec @ 11kHz with 
                                 %% 128 sone hopsize)
      p.sequence.hopsize = p.fft_size;  
      p.sequence.windowfunction = 'boxcar';
      p.visu = 0;                %% do some visualizations
%spanned by the frequency range
%62.5...8000

out_p = p;